@@ -43,10 +43,11 @@ class get_data:
     def __init__(self,directory=None,id=None,test=None,timestep=10):
         self.timestep=timestep
         if test:
-            self.directory = str((Path.home()) / '.nufeb_tools' / 'data' / 'Run_60_18_63_1_2021-06-23')
+            self.directory = str((Path.home()) / '.nufeb_tools' / 'data' / 'Run_75_83_21_1_2021-12-03_977840')
             if not os.path.isdir(self.directory):
                 download_test_data()     
             self.get_local_data()
+            self.sucRatio = int(self.directory.split('_')[3])
         elif directory:
             self.directory = directory
             self.get_local_data()
